from setuptools import setup

setup(name='simp_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['simp_distributions'],
      author = 'Timilehin Aderinola',
      author_email = 'timiderinola@gmail.com',
      zip_safe=False)
